import { z } from 'zod';
import { GitHubClient } from '../github-client.js';
declare const ResolveCommentSchema: z.ZodObject<{
    owner: z.ZodString;
    repo: z.ZodString;
    commentId: z.ZodNumber;
    resolution: z.ZodDefault<z.ZodEnum<["addressed", "wont_fix", "not_applicable"]>>;
    note: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    owner: string;
    repo: string;
    commentId: number;
    resolution: "addressed" | "wont_fix" | "not_applicable";
    note?: string | undefined;
}, {
    owner: string;
    repo: string;
    commentId: number;
    resolution?: "addressed" | "wont_fix" | "not_applicable" | undefined;
    note?: string | undefined;
}>;
export type ResolveCommentInput = z.infer<typeof ResolveCommentSchema>;
export interface ResolveCommentResult {
    success: boolean;
    message: string;
    comment_id: number;
    resolution_method: string;
}
/**
 * Mark a CodeRabbit comment as resolved or addressed
 *
 * Note: GitHub doesn't provide a direct API to "resolve" pull request comments
 * like it does for review comments. This function implements several strategies:
 * 1. Add a reply comment indicating resolution
 * 2. React to the comment with a thumbs up
 * 3. Track resolution status internally
 */
export declare function resolveComment(input: ResolveCommentInput, githubClient: GitHubClient): Promise<ResolveCommentResult>;
export {};
//# sourceMappingURL=resolve-comment.d.ts.map