import { z } from 'zod';
import { GitHubClient } from '../github-client.js';
declare const ResolveConversationSchema: z.ZodObject<{
    owner: z.ZodString;
    repo: z.ZodString;
    commentId: z.ZodNumber;
    resolved: z.ZodDefault<z.ZodBoolean>;
    note: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    owner: string;
    repo: string;
    commentId: number;
    resolved: boolean;
    note?: string | undefined;
}, {
    owner: string;
    repo: string;
    commentId: number;
    note?: string | undefined;
    resolved?: boolean | undefined;
}>;
export type ResolveConversationInput = z.infer<typeof ResolveConversationSchema>;
export interface ResolveConversationResult {
    success: boolean;
    message: string;
    comment_id: number;
    resolved: boolean;
    resolution_method: string;
    error_details?: string;
}
/**
 * Resolve or unresolve a GitHub pull request review conversation
 *
 * This function marks a conversation thread as resolved in GitHub's UI,
 * which is different from just adding a comment about resolution.
 * It uses GitHub's conversation resolution API when available.
 */
export declare function resolveConversation(input: ResolveConversationInput, githubClient: GitHubClient): Promise<ResolveConversationResult>;
export {};
//# sourceMappingURL=resolve-conversation.d.ts.map